//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// G4SDStructure
//
// Class description:
//
// This class is exclusively used by G4SDManager for handling the tree
// structure of the user's sensitive detector names.
//
// Author: Makoto Asai
// --------------------------------------------------------------------
#ifndef G4SDStructure_h
#define G4SDStructure_h 1

// Globals
#include "G4VSensitiveDetector.hh"
#include "globals.hh"

#include <vector>

class G4HCofThisEvent;

class G4SDStructure
{
 public:
  G4SDStructure(const G4String& aPath);
  ~G4SDStructure();

  G4bool operator==(const G4SDStructure& right) const;

  void AddNewDetector(G4VSensitiveDetector* aSD, const G4String& treeStructure);
  void Activate(const G4String& aName, G4bool sensitiveFlag);
  void Initialize(G4HCofThisEvent* HCE);
  void Terminate(G4HCofThisEvent* HCE);
  G4VSensitiveDetector* FindSensitiveDetector(const G4String& aName, G4bool warning = true);
  G4VSensitiveDetector* GetSD(const G4String& aName);
  void ListTree();

  inline void SetVerboseLevel(G4int vl)
  {
    verboseLevel = vl;
    for (auto& i : structure) {
      i->SetVerboseLevel(vl);
    }
    for (auto& j : detector) {
      j->SetVerboseLevel(vl);
    }
  };

 private:
  G4SDStructure* FindSubDirectory(const G4String& subD);
  G4String ExtractDirName(const G4String& aPath);
  void RemoveSD(G4VSensitiveDetector*);

 private:
  std::vector<G4SDStructure*> structure;
  std::vector<G4VSensitiveDetector*> detector;
  G4String pathName;
  G4String dirName;
  G4int verboseLevel{0};
};

#endif
